/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.newsletter.tree');

org.ametys.newsletter.tree.NewslettersXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.newsletter.tree.NewslettersXmlLoader.prototype.processResponse = function(response, node, callback) 
{
	this._nodeTags = {};
	this._nodeTags['provider'] = '';
	this._nodeTags['category'] = '';
	this._nodeTags['newsletter'] = '';
	
	org.ametys.newsletter.tree.NewslettersXmlLoader.superclass.processResponse.call(this, response, node, callback);
}

org.ametys.newsletter.tree.NewslettersXmlLoader.prototype.processAttributes = function(attr)
{
	org.ametys.newsletter.tree.NewslettersXmlLoader.superclass.processAttributes.call(this, attr);
	
	// Node text 
	attr.text = attr.title ? attr.title : attr.name;
	
	// Node icon
	switch (attr.tagName) {
		case "provider":
			attr.icon = getPluginResourcesUrl('newsletter') + '/img/category/provider_16.png';
			attr.type = "provider";
			attr.leafSort = false; // attribute for sorting
			break;
		case "category":
			attr.icon = getPluginResourcesUrl('newsletter') + '/img/category/category_16.png';
			attr.type = "category";
			attr.leafSort = false; // attribute for sorting
			break;
		case "newsletter":
		    var iconName = (attr.automatic == 'true' ? 'newsletter_automatic_16.png' : 'newsletter_16.png');
			attr.icon = getPluginResourcesUrl('newsletter') + '/img/' + iconName;
			attr.type = "newsletter";
			attr.leafSort = true; // attribute for sorting
			break;
		default:
			break;
	}
	
	if (!attr.hasChild)
    {
   	 	attr.leaf = true;
    }
    if (this.checkMode && attr.type != "provider")
    {
   	 	attr.checked = false;
    }
    
    if (this.syncMode)
    {
   	 	// Override these values for our folder nodes because we are loading all data at once.  If we were
        // loading each node asynchronously (the default) we would not want to do this:
        attr.expanded = true;
    	attr.loaded = true;
    }
}

org.ametys.newsletter.tree.NewslettersXmlLoader.prototype.createNode = function(node) 
{
	var attr = {
		tagName :node.tagName
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});
	
	this._currentXMLNode = node;
	this.processAttributes(attr);
	delete this._currentXMLNode;
	
	if (this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if (this.applyLoader !== false)
    {
        attr.loader = this;
    }
    if (typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
    if (attr.tagName == "category" || attr.tagName == "provider")
    {
    	return new Ext.tree.AsyncTreeNode(attr);
    }
    else
    {
    	return new Ext.tree.TreeNode(attr);
    }
}
